@@ -22,12 +22,10 @@ from ...models import Singleton
 from ...utils import init_layouts
 from ...utils import init_objects
 from ..aliases import app
-from ..aliases import tr
 from ..menus import HelpContextMenu
 from ..menus import ToolsContextMenu
+from ..widgets import ConversationView
 from ..widgets import ExceptionLogger
-from ..widgets import ExternalTextBrowser
-from ..widgets import PasteLineEdit
 
 
 def size_label_for(num: int) -> str:
@@ -56,8 +54,7 @@ class AppWindow(Singleton, QMainWindow):
         super().__init__()
 
         self.resize(size)
-
-        app().client.receivedMessage.connect(self.receive_message)
+        self.conversation_counter: int = 0
 
         self._init_toolbar()
         self._init_ui()
@@ -140,28 +137,47 @@ class AppWindow(Singleton, QMainWindow):
     # noinspection PyTypeChecker
     def _init_ui(self) -> None:
         """Initialize the UI, including Layouts and widgets."""
+        def add_conversation():
+            self.conversation_counter += 1
+            self.conversation_tabs.addTab(ConversationView(), f'Conversation {self.conversation_counter}')
+
+        def remove_conversation(index: int):
+            view: ConversationView = self.conversation_tabs.widget(index)  # type: ignore
+            view.deleteLater()
+
+            self.conversation_tabs.removeTab(index)
+            if not self.conversation_tabs.count():
+                self.conversation_counter = 0
+                add_conversation()
+
         # Define widget attributes
         # Cannot be defined in init_objects() as walrus operators are not allowed for object attribute assignment.
         # This works in the standard AST, but is a seemingly arbitrary limitation set by the interpreter.
         # See:
         # https://stackoverflow.com/questions/64055314/why-cant-pythons-walrus-operator-be-used-to-set-instance-attributes#answer-66617839
-        self.output, self.input = ExternalTextBrowser(self), PasteLineEdit(self)
+        self.conversation_tabs = QTabWidget(self)
 
         init_objects({
-            self.input: {
-                'returnPressed': self.send_message
+            self.conversation_tabs: {
+                'tabsClosable': True,
+                'tabCloseRequested': remove_conversation
+            },
+
+            (add_conversation_button := QPushButton(self.conversation_tabs)): {
+                'size': {'fixed': (None, 26)},
+                'icon': app().icon_store['add'],
+                'clicked': add_conversation
             }
+
         })
 
-        app().init_translations({
-            self.output.setPlaceholderText: 'gui.output_text.placeholder',
-            self.input.setPlaceholderText: 'gui.input_field.placeholder'
-        })
+        add_conversation()
+        self.conversation_tabs.setCornerWidget(add_conversation_button, Qt.Corner.TopLeftCorner)
 
         init_layouts({
             # Main layout
             (layout := QVBoxLayout()): {
-                'items': [self.output, self.input]
+                'items': (self.conversation_tabs,)
             }
         })
 
@@ -171,39 +187,6 @@ class AppWindow(Singleton, QMainWindow):
             self: {'centralWidget': main_widget}
         })
 
-    def append_to_output(self, text: str) -> None:
-        """Append some new text to the output.
-
-        Adds two newlines after the text for better differentiation between messages.
-
-        :param text: Text to append to output.
-        """
-        self.output.setText(f'{self.output.toPlainText()}{text}\n\n')
-
-    def send_message(self) -> None:
-        """Send a message to the client using the current input text.
-
-        Clears the input and disables after sending.
-        """
-        message: str = self.input.text()
-        self.input.clear()
-        self.input.setDisabled(True)
-        self.append_to_output(tr('gui.output_text.you_prompt', message))
-
-        app().client.send_message(message)
-
-    def receive_message(self, message: str) -> None:
-        """Receive a response from the client.
-
-        Re-enables the input and appends the response to the output.
-
-        :param message: Message received.
-        """
-        self.append_to_output(tr('gui.output_text.ai_prompt', message))
-
-        self.input.setDisabled(False)
-        self.input.setFocus()
-
     # # # # # Events
 
     def show(self) -> None:
